# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.0.6] - 2022-03-01

### Added

- Modules
  - `cmsquery`: Makes querying the CMS easier.
  - `cmsquery_utils`: Helps you writing an actual query statement.

### Fixed

- Version Badge in README.md 😂
- Minor fixes

## [0.0.5] - 2022-02-23

### Added

- Basic functionality
- `http` module
  - `get` function
  - `post` function
- `token` module
  - `request` function
  - `invalidate` function
